%% Material class
%
% This is a class in the Object Oriented Programming (OOP) paradigm
% that defines material objects in the <main.html LESM (Linear Elements
% Structure Model)> program.
%
%% Authors
% Luiz Fernando Martha and Rafael Lopez Rangel
%
%% History
% @version 1.00
%
% Initial version: August-December 2016
%%%
% Prepared for the course ENG 1240 - Anlise de Estruturas III, 2016.2,
% Department of Civil Engineering, PUC-Rio.
%
classdef Material < hgsetget
    %%
    % <http://www.mathworks.com/help/matlab/handle-classes.html
    % See documentation on *hgsetget* handle super-class>.

    %% Public attributes
    properties (SetAccess = public, GetAccess = public)
        id = 0;           % material identification number
        elasticity = 0;   % material elasticity modulus
        poisson = 0;      % material poisson ratio
        shear = 0;        % material shear modulus
        thermexp = 0;     % material thermal expansion coefficient
    end

    methods
        %-----------------------------------------------------------------------
        function obj = Material(id,e,v,te)
            if (nargin > 0)
                obj.id = id;
                obj.elasticity = e;
                obj.poisson = v;
                obj.shear = e / (2.0*(1.0 + v));
                obj.thermexp = te;
            end
        end
    end

    %% Public set methods
    methods
        %-----------------------------------------------------------------------
        % Set material id number
        function obj = set.id(obj,id)
            obj.id = id;
        end

        %-----------------------------------------------------------------------
        % Set elasticity modulus value and calculate shear modulus value
        function obj = set.elasticity(obj,e)
            obj.elasticity = e;
            obj.set('shear',e);
        end

        %-----------------------------------------------------------------------
        % Set poisson ratio value and calculate shear modulus value
        function obj = set.poisson(obj,v)
            obj.poisson = v;
            obj.set('shear',v);
        end

        %-----------------------------------------------------------------------
        % Set shear modulus value based on elasticity modulus and
        % possion ratio
        function obj = set.shear(obj,val)
            if(val >= 0.0)
                e = obj.get('elasticity');
                v = obj.get('poisson');
                obj.shear = e / (2.0*(1.0 + v));
            end
        end

        %-----------------------------------------------------------------------
        % Set material thermal expansion coefficient
        function obj = set.thermexp(obj,te)
            obj.thermexp = te;
        end
    end

    %% Public get methods
    methods
        %-----------------------------------------------------------------------
        % Get material id number
        function id = get.id(obj)
            id = obj.id;
        end

        %-----------------------------------------------------------------------
        % Get elasticity modulus value
        function e = get.elasticity(obj)
            e = obj.elasticity;
        end

        %-----------------------------------------------------------------------
        % Get poisson ratio value
        function v = get.poisson(obj)
            v = obj.poisson;
        end

        %-----------------------------------------------------------------------
        % Get shear modulus value
        function g = get.shear(obj)
            g = obj.shear;
        end

        %-----------------------------------------------------------------------
        % Get shear modulus value
        function te = get.thermexp(obj)
            te = obj.thermexp;
        end
    end

    %% Public methods
    methods
        %-----------------------------------------------------------------------
        % Cleans data structure of a material object
        function obj = clean(obj)
            obj.id = 0;
            obj.elasticity = 0;
            obj.poisson = 0;
            obj.shear = 0;
            obj.thermexp = 0;
        end
    end
end