%% Section class
%
% This is a class in the Object Oriented Programming (OOP) paradigm
% that defines cross-section objects in the <main.html LESM (Linear
% Elements Structure Model)>) program.
%
%% Authors
% Luiz Fernando Martha and Rafael Lopez Rangel
%
%% History
% @version 1.00
%
% Initial version: August-December 2016
%%%
% Prepared for the course ENG 1240 - Anlise de Estruturas III, 2016.2,
% Department of Civil Engineering, PUC-Rio.
%
classdef Section < hgsetget
    %%
    % <http://www.mathworks.com/help/matlab/handle-classes.html
    % See documentation on *hgsetget* handle super-class>.

    %% Public attributes
    properties (SetAccess = public, GetAccess = public)
        id = 0;          % cross section identification number
        area_X = 0;      % cross section area relative to local axis x (full area)
        area_Y = 0;      % cross section area relative to local axis y (effective shear area)
        area_Z = 0;      % cross section area relative to local axis z (effective shear area)
        inertia_X = 0;   % cross section moment of inertia realative to local axis x (torsion inertia)
        inertia_Y = 0;   % cross section moment of inertia realative to local axis y (bending inertia)
        inertia_Z = 0;   % cross section moment of inertia realative to local axis z (bending inertia)
        cw = 0;          % cross section warping torsional constant
        height_Y = 0;    % cross section height on local axis y
        height_Z = 0;    % cross section height on local axis z
    end

    %% Constructor method
    methods
        %-----------------------------------------------------------------------
        function obj = Section(id,Ax,Ay,Az,Ix,Iy,Iz,cw,Hy,Hz)
            if (nargin > 0)
                obj.id = id;
                obj.area_X = Ax;
                obj.area_Y = Ay;
                obj.area_Z = Az;
                obj.inertia_X = Ix;
                obj.inertia_Y = Iy;
                obj.inertia_Z = Iz;
                obj.cw = cw;
                obj.height_Y = Hy;
                obj.height_Z = Hz;
            end
        end
    end

    %% Public set methods
    methods
        %-----------------------------------------------------------------------
        % Set cross section id number
        function obj = set.id(obj,id)
            obj.id = id;
        end

        %-----------------------------------------------------------------------
        % Set cross section area relative to local axis x (full area)
        function obj = set.area_X(obj,Ax)
            obj.area_X = Ax;
        end

        %-----------------------------------------------------------------------
        % Set cross section area relative to local axis y (effective shear area)
        function obj = set.area_Y(obj,Ay)
            obj.area_Y = Ay;
        end

        %-----------------------------------------------------------------------
        % Set cross section area relative to local axis z (effective shear area)
        function obj = set.area_Z(obj,Az)
            obj.area_Z = Az;
        end

        %-----------------------------------------------------------------------
        % Set cross section moment of inertia realative to local axis x
        % (torsion inertia)
        function obj = set.inertia_X(obj,Ix)
            obj.inertia_X = Ix;
        end

        %-----------------------------------------------------------------------
        % Set cross section moment of inertia realative to local axis y
        % (bending inertia)
        function obj = set.inertia_Y(obj,Iy)
            obj.inertia_Y = Iy;
        end

        %-----------------------------------------------------------------------
        % Set cross section moment of inertia realative to local axis z
        % (bending inertia)
        function obj = set.inertia_Z(obj,Iz)
            obj.inertia_Z = Iz;
        end

        %-----------------------------------------------------------------------
        % Set cross section warping torsional constant
        function obj = set.cw(obj,cw)
            obj.cw = cw;
        end

        %-----------------------------------------------------------------------
        % Set cross section height on local axis y
        function obj = set.height_Y(obj,Hy)
            obj.height_Y = Hy;
        end

        %-----------------------------------------------------------------------
        % Set cross section height on local axis z
        function obj = set.height_Z(obj,Hz)
            obj.height_Z = Hz;
        end
    end

    %% Public get methods
    methods
        %-----------------------------------------------------------------------
        % Get cross section id number
        function id = get.id(obj)
            id = obj.id;
        end

        %-----------------------------------------------------------------------
        % Get cross section area relative to local axis x (full area)
        function Ax = get.area_X(obj)
            Ax = obj.area_X;
        end

        %-----------------------------------------------------------------------
        % Get cross section area relative to local axis y (effective shear area)
        function Ay = get.area_Y(obj)
            Ay = obj.area_Y;
        end

        %-----------------------------------------------------------------------
        % Get cross section area relative to local axis z (effective shear area)
        function Az = get.area_Z(obj)
            Az = obj.area_Z;
        end

        %-----------------------------------------------------------------------
        % Get cross section moment of inertia realative to local axis x
        % (torsion inertia)
        function Ix = get.inertia_X(obj)
            Ix = obj.inertia_X;
        end

        %-----------------------------------------------------------------------
        % Get cross section moment of inertia realative to local axis y
        % (bending inertia)
        function Iy = get.inertia_Y(obj)
            Iy = obj.inertia_Y;
        end

        %-----------------------------------------------------------------------
        % Get cross section moment of inertia realative to local axis z
        % (bending inertia)
        function Iz = get.inertia_Z(obj)
            Iz = obj.inertia_Z;
        end

        %-----------------------------------------------------------------------
        % Get cross section warping torsional constant
        function cw = get.cw(obj)
            cw = obj.cw;
        end

        %-----------------------------------------------------------------------
        % Get cross section height on local axis y
        function Hy = get.height_Y(obj)
            Hy = obj.height_Y;
        end

        %-----------------------------------------------------------------------
        % Get cross section height on local axis z
        function Hz = get.height_Z(obj)
            Hz = obj.height_Z;
        end
    end

    %% Public methods
    methods
        %-----------------------------------------------------------------------
        % Cleans data structure of a cross section object
        function obj = clean(obj)
            obj.id = 0;
            obj.area_X = 0;
            obj.area_Y = 0;
            obj.area_Z = 0;
            obj.inertia_X = 0;
            obj.inertia_Y = 0;
            obj.inertia_Z = 0;
            obj.cw = 0;
            obj.height_Y = 0;
            obj.height_Z = 0;
        end
    end
end